==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tavaliselt saab selle lahendada andes veebiserverile seatete kataloogile \"config\" kirjutusõigused",
    "See %s" : "Vaata %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Tavaliselt saab selle lahendada %s andes veebiserverile seadete kataloogile \"config\" kirjutusõigused %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "Following databases are supported: %s" : "Toetatud on järgnevad andmebaasid: %s",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Following platforms are supported: %s" : "Toetatud on järgnevad platformid: %s",
    "ownCloud %s or higher is required." : "ownCloud %s või uuem on nõutav.",
    "ownCloud %s or lower is required." : "ownCloud %s või vanem on nõutav.",
    "Help" : "Abiinfo",
    "Personal" : "Isiklik",
    "Users" : "Kasutajad",
    "Admin" : "Admin",
    "Recommended" : "Soovitatud",
    "No app name specified" : "Ühegi rakendi nime pole määratletud",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "today" : "täna",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "last month" : "viimasel kuul",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "seconds ago" : "sekundit tagasi",
    "web services under your control" : "veebitenused sinu kontrolli all",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "Can't read file" : "Faili lugemine ebaõnnestus",
    "App directory already exists" : "Rakenduse kataloog on juba olemas",
    "Can't create app folder. Please fix permissions. %s" : "Ei saa luua rakendi kataloogi. Palun korrigeeri õigusi. %s",
    "No source specified when installing app" : "Ühegi lähteallikat pole rakendi paigalduseks määratletud",
    "No href specified when installing app from http" : "Ühtegi aadressi pole määratletud rakendi paigalduseks veebist",
    "No path specified when installing app from local file" : "Ühtegi teed pole määratletud paigaldamaks rakendit kohalikust failist",
    "Archives of type %s are not supported" : "%s tüüpi arhiivid pole toetatud",
    "Failed to open archive when installing app" : "Arhiivi avamine ebaõnnestus rakendi paigalduse käigus",
    "App does not provide an info.xml file" : "Rakend ei paku ühtegi info.xml faili",
    "App can't be installed because of not allowed code in the App" : "Rakendit ei saa paigaldada, kuna sisaldab lubamatud koodi",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Rakendit ei saa paigaldada, kuna see pole ühilduv selle ownCloud versiooniga.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Rakendit ei saa paigaldada, kuna see sisaldab \n<shipped>\n\ntrue\n</shipped>\nmärgendit, mis pole lubatud mitte veetud (non shipped) rakendites",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Rakendit ei saa paigaldada, kuna selle versioon info.xml/version pole sama, mis on märgitud rakendite laos.",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "Unknown user" : "Tundmatu kasutaja",
    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
    "DB Error: \"%s\"" : "Andmebaasi viga: \"%s\"",
    "Offending command was: \"%s\"" : "Tõrkuv käsk oli: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Sisesta kas juba olemasolev konto või administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Tõrkuv käsk oli: \"%s\", nimi: %s, parool: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin username." : "Määra admin kasutajanimi.",
    "Set an admin password." : "Määra admini parool.",
    "Can't create or write into the data directory %s" : "Ei suuda luua või kirjutada andmete kataloogi %s",
    "%s shared »%s« with you" : "%s jagas sinuga »%s«",
    "%s via %s" : "%s läbi %s",
    "Sharing %s failed, because the file does not exist" : "%s jagamine ebaõnnestus, kuna faili pole olemas",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Sharing %s failed, because the user %s is the item owner" : "%s jagamine ebaõnnestus, kuna kuna kasutaja %s on üksuse omanik",
    "Sharing %s failed, because the user %s does not exist" : "%s jagamine ebaõnnestus, kuna kasutajat %s pole olemas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s jagamine ebaõnnestus, kuna kasutaja %s pole ühegi grupi liige, millede liige on %s",
    "Sharing %s failed, because this item is already shared with %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud %s",
    "Sharing %s failed, because the group %s does not exist" : "%s jagamine ebaõnnestus, kuna gruppi %s pole olemas",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s jagamine ebaõnnestus, kuna %s pole grupi %s liige",
    "You need to provide a password to create a public link, only protected links are allowed" : "Avaliku viite tekitamiseks pead sisestama parooli, ainult kaitstud viited on lubatud",
    "Sharing %s failed, because sharing with links is not allowed" : "%s jagamine ebaõnnestus, kuna linkidega jagamine pole lubatud",
    "Share type %s is not valid for %s" : "Jagamise tüüp %s ei ole õige %s jaoks",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Lubade seadistus %s jaoks ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
    "Setting permissions for %s failed, because the item was not found" : "Lubade seadistus %s jaoks ebaõnnestus, kuna üksust ei leitud",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Aegumise kuupäeva ei saa määrata. Jagamised ei saa aeguda hiljem kui %s peale jagamist.",
    "Cannot set expiration date. Expiration date is in the past" : "Aegumiskuupäeva ei saa määrata. Aegumise kuupäev on minevikus",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Aegumise kuupäeva ei saa tühjendada. Jagamistel peab olema aegumise kuupäev.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "Sharing %s failed, because the user %s is the original sharer" : "%s jagamine ebaõnnestus, kuna kasutaja %s on algne jagaja",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s jagamine ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
    "Sharing %s failed, because resharing is not allowed" : "%s jagamine ebaõnnestus, kuna edasijagamine pole lubatud",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s jagamine ebaõnnestus, kuna jagamise tagarakend ei suutnud leida %s jaoks lähteallikat",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s jagamine ebaõnnestus, kuna faili ei suudetud leida failide puhvrist",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Apps" : "Rakendused",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Kasutajanimes on lubatud ainult järgnevad tähemärgid: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-\"",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "The username is already being used" : "Kasutajanimi on juba kasutuses",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows platform pole toetatud",
    "Cannot write into \"config\" directory" : "Ei saa kirjutada \"config\" kataloogi",
    "Cannot write into \"apps\" directory" : "Ei saa kirjutada \"apps\" kataloogi!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Tavaliselt saab selle lahendada %s andes veebiserverile rakendite kataloogile kirjutusõigused %s või keelates seadetes rakendikogu.",
    "Cannot create \"data\" directory (%s)" : "Ei suuda luua \"data\" kataloogi (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Tavaliselt saab selle lahendada <a href=\"%s\" target=\"_blank\">andes veebiserverile juur-kataloogile kirjutusõigused</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Õigused saab tavaliselt paika %s andes veebiserverile juurkataloogile kirjutusõigused %s",
    "Setting locale to %s failed" : "Lokaadi %s määramine ebaõnnestus.",
    "Please install one of these locales on your system and restart your webserver." : "Palun paigalda mõni neist lokaatides oma süsteemi ning taaskäivita veebiserver.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav",
    "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni",
    "Error occurred while checking PostgreSQL version" : "Viga PostgreSQL versiooni kontrollimisel",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Palun veendu, et kasutad PostgreSQL >=9 või vaata logidest vea kohta detailsemat informatsiooni",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
    "Data directory (%s) is readable by other users" : "Andmete kataloog (%s) on teistele kasutajate loetav",
    "Data directory (%s) is invalid" : "Andmete kataloog (%s) pole korrektne",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Palun veendu, et andmete kataloogis sisaldub fail \".ocdata\" ",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\"."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/et_EE.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ei saa kirjutada \"config\" kataloogi!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tavaliselt saab selle lahendada andes veebiserverile seatete kataloogile \"config\" kirjutusõigused",
    "See %s" : "Vaata %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Tavaliselt saab selle lahendada %s andes veebiserverile seadete kataloogile \"config\" kirjutusõigused %s",
    "Sample configuration detected" : "Tuvastati näidisseaded",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Tuvastati, et kopeeriti näidisseaded. See võib lõhkuda sinu saidi ja see pole toetatud. Palun loe enne faili config.php muutmist dokumentatsiooni",
    "PHP %s or higher is required." : "PHP %s või uuem on nõutav.",
    "PHP with a version lower than %s is required." : "Nõutud on PHP madalama versiooniga kui %s.",
    "Following databases are supported: %s" : "Toetatud on järgnevad andmebaasid: %s",
    "The command line tool %s could not be found" : "Käsurea töövahendit %s ei leitud",
    "The library %s is not available." : "Teek %s pole saadaval.",
    "Following platforms are supported: %s" : "Toetatud on järgnevad platformid: %s",
    "ownCloud %s or higher is required." : "ownCloud %s või uuem on nõutav.",
    "ownCloud %s or lower is required." : "ownCloud %s või vanem on nõutav.",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "today" : "täna",
    "yesterday" : "eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "last month" : "viimasel kuul",
    "last year" : "viimasel aastal",
    "_%n year ago_::_%n years ago_" : ["%n aasta tagasi","%n aastat tagasi"],
    "seconds ago" : "sekundit tagasi",
    "Empty filename is not allowed" : "Tühi failinimi pole lubatud",
    "Dot files are not allowed" : "Punktiga failid pole lubatud",
    "File name is a reserved word" : "Failinimi sisaldab keelatud sõna",
    "File name contains at least one invalid character" : "Faili nimesonvähemalt üks keelatud märk",
    "File name is too long" : "Faili nimi on liiga pikk",
    "App directory already exists" : "Rakenduse kataloog on juba olemas",
    "Can't create app folder. Please fix permissions. %s" : "Ei saa luua rakendi kataloogi. Palun korrigeeri õigusi. %s",
    "No source specified when installing app" : "Ühegi lähteallikat pole rakendi paigalduseks määratletud",
    "No href specified when installing app from http" : "Ühtegi aadressi pole määratletud rakendi paigalduseks veebist",
    "No path specified when installing app from local file" : "Ühtegi teed pole määratletud paigaldamaks rakendit kohalikust failist",
    "Archives of type %s are not supported" : "%s tüüpi arhiivid pole toetatud",
    "Failed to open archive when installing app" : "Arhiivi avamine ebaõnnestus rakendi paigalduse käigus",
    "App does not provide an info.xml file" : "Rakend ei paku ühtegi info.xml faili",
    "App can't be installed because of not allowed code in the App" : "Rakendit ei saa paigaldada, kuna sisaldab lubamatud koodi",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Rakendit ei saa paigaldada, kuna see pole ühilduv selle ownCloud versiooniga.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Rakendit ei saa paigaldada, kuna see sisaldab \n<shipped>\n\ntrue\n</shipped>\nmärgendit, mis pole lubatud mitte veetud (non shipped) rakendites",
    "%s enter the database username." : "%s sisesta andmebaasi kasutajatunnus.",
    "%s enter the database name." : "%s sisesta andmebaasi nimi.",
    "%s you may not use dots in the database name" : "%s punktide kasutamine andmebaasi nimes pole lubatud",
    "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
    "Oracle username and/or password not valid" : "Oracle kasutajatunnus ja/või parool pole õiged",
    "DB Error: \"%s\"" : "Andmebaasi viga: \"%s\"",
    "Offending command was: \"%s\"" : "Tõrkuv käsk oli: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Sisesta kas juba olemasolev konto või administrator.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Tõrkuv käsk oli: \"%s\", nimi: %s, parool: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL kasutajatunnus ja/või parool pole õiged",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
    "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
    "Set an admin username." : "Määra admin kasutajanimi.",
    "Set an admin password." : "Määra admini parool.",
    "Can't create or write into the data directory %s" : "Ei suuda luua või kirjutada andmete kataloogi %s",
    "%s shared »%s« with you" : "%s jagas sinuga »%s«",
    "%s via %s" : "%s läbi %s",
    "Sharing %s failed, because the file does not exist" : "%s jagamine ebaõnnestus, kuna faili pole olemas",
    "You are not allowed to share %s" : "Sul pole lubatud %s jagada",
    "Sharing %s failed, because the user %s does not exist" : "%s jagamine ebaõnnestus, kuna kasutajat %s pole olemas",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s jagamine ebaõnnestus, kuna kasutaja %s pole ühegi grupi liige, millede liige on %s",
    "Sharing %s failed, because this item is already shared with %s" : "%s jagamine ebaõnnestus, kuna see üksus on juba jagatud %s",
    "Sharing %s failed, because the group %s does not exist" : "%s jagamine ebaõnnestus, kuna gruppi %s pole olemas",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s jagamine ebaõnnestus, kuna %s pole grupi %s liige",
    "You need to provide a password to create a public link, only protected links are allowed" : "Avaliku viite tekitamiseks pead sisestama parooli, ainult kaitstud viited on lubatud",
    "Sharing %s failed, because sharing with links is not allowed" : "%s jagamine ebaõnnestus, kuna linkidega jagamine pole lubatud",
    "Share type %s is not valid for %s" : "Jagamise tüüp %s ei ole õige %s jaoks",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Lubade seadistus %s jaoks ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
    "Setting permissions for %s failed, because the item was not found" : "Lubade seadistus %s jaoks ebaõnnestus, kuna üksust ei leitud",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Aegumise kuupäeva ei saa määrata. Jagamised ei saa aeguda hiljem kui %s peale jagamist.",
    "Cannot set expiration date. Expiration date is in the past" : "Aegumiskuupäeva ei saa määrata. Aegumise kuupäev on minevikus",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Aegumise kuupäeva ei saa tühjendada. Jagamistel peab olema aegumise kuupäev.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Jagamise tagarakend %s peab kasutusele võtma OCP\\Share_Backend liidese",
    "Sharing backend %s not found" : "Jagamise tagarakendit %s ei leitud",
    "Sharing backend for %s not found" : "Jagamise tagarakendit %s jaoks ei leitud",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s jagamine ebaõnnestus, kuna antud õigused ületavad %s jaoks määratud õigusi",
    "Sharing %s failed, because resharing is not allowed" : "%s jagamine ebaõnnestus, kuna edasijagamine pole lubatud",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s jagamine ebaõnnestus, kuna jagamise tagarakend ei suutnud leida %s jaoks lähteallikat",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s jagamine ebaõnnestus, kuna faili ei suudetud leida failide puhvrist",
    "Expiration date is in the past" : "Aegumise kuupäev on minevikus",
    "Could not find category \"%s\"" : "Ei leia kategooriat \"%s\"",
    "Apps" : "Rakendused",
    "A valid username must be provided" : "Sisesta nõuetele vastav kasutajatunnus",
    "A valid password must be provided" : "Sisesta nõuetele vastav parool",
    "The username is already being used" : "Kasutajanimi on juba kasutuses",
    "Help" : "Abiinfo",
    "Personal" : "Isiklik",
    "Users" : "Kasutajad",
    "Admin" : "Admin",
    "Recommended" : "Soovitatud",
    "No app name specified" : "Ühegi rakendi nime pole määratletud",
    "web services under your control" : "veebitenused sinu kontrolli all",
    "Can't read file" : "Faili lugemine ebaõnnestus",
    "Application is not enabled" : "Rakendus pole sisse lülitatud",
    "Authentication error" : "Autentimise viga",
    "Token expired. Please reload page." : "Kontrollkood aegus. Paelun lae leht uuesti.",
    "Unknown user" : "Tundmatu kasutaja",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ühtegi andmebaasi (sqlite, mysql või postgresql) draiverit pole paigaldatud.",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows platform pole toetatud",
    "Cannot write into \"config\" directory" : "Ei saa kirjutada \"config\" kataloogi",
    "Cannot write into \"apps\" directory" : "Ei saa kirjutada \"apps\" kataloogi!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Tavaliselt saab selle lahendada %s andes veebiserverile rakendite kataloogile kirjutusõigused %s või keelates seadetes rakendikogu.",
    "Cannot create \"data\" directory (%s)" : "Ei suuda luua \"data\" kataloogi (%s)",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Õigused saab tavaliselt paika %s andes veebiserverile juurkataloogile kirjutusõigused %s",
    "Setting locale to %s failed" : "Lokaadi %s määramine ebaõnnestus.",
    "Please install one of these locales on your system and restart your webserver." : "Palun paigalda mõni neist lokaatides oma süsteemi ning taaskäivita veebiserver.",
    "Please ask your server administrator to install the module." : "Palu oma serveri haldajal moodul paigadalda.",
    "PHP module %s not installed." : "PHP moodulit %s pole paigaldatud.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "See on tõenäoliselt põhjustatud puhver/kiirendist nagu Zend OPcache või eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moodulid on paigaldatud, kuid neid näitatakse endiselt kui puuduolevad?",
    "Please ask your server administrator to restart the web server." : "Palu oma serveri haldajal veebiserver taaskäivitada.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 on nõutav",
    "Please upgrade your database version" : "Palun uuenda oma andmebaasi versiooni",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Palun muuda kataloogi õigused 0770-ks, et kataloogi sisu poleks teistele kasutajatele nähtav",
    "Data directory (%s) is readable by other users" : "Andmete kataloog (%s) on teistele kasutajate loetav",
    "Data directory (%s) is invalid" : "Andmete kataloog (%s) pole korrektne",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Palun veendu, et andmete kataloogis sisaldub fail \".ocdata\" ",
    "Could not obtain lock type %d on \"%s\"." : "Ei suutnud hankida %d tüüpi lukustust \"%s\".",
    "Storage not available" : "Andmehoidla pole saadaval"
},
"nplurals=2; plural=(n != 1);");
